@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,7 +19,8 @@
  */
 CKEDITOR.lang[ 'zh-cn' ] = {
 	// ARIA description.
-	editor: '所见即所得编辑器',
+	application: '富文本编辑器',
+	editor: '编辑器',
 	editorPanel: '所见即所得编辑器面板',
 
 	// Common messages and labels.
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'zh-cn' ] = {
 		upload: '上传',
 		uploadSubmit: '上传到服务器',
 		image: '图像',
-		flash: 'Flash',
 		form: '表单',
 		checkbox: '复选框',
 		radio: '单选按钮',
