@@ -1,10 +1,10 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'format', 'sr-latn', {
 	label: 'Format',
-	panelTitle: 'Format',
+	panelTitle: 'Format pasusa',
 	tag_address: 'Adresa',
 	tag_div: 'Normalno (DIV)',
 	tag_h1: 'Naslov 1',
@@ -13,6 +13,6 @@ CKEDITOR.plugins.setLang( 'format', 'sr-latn', {
 	tag_h4: 'Naslov 4',
 	tag_h5: 'Naslov 5',
 	tag_h6: 'Naslov 6',
-	tag_p: 'Normal',
+	tag_p: 'Normalno',
 	tag_pre: 'Formatirano'
 } );
