@@ -1,6 +1,6 @@
 ﻿/**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 /**
@@ -60,7 +60,7 @@
 			for ( var i = 0, count = listNode.getChildCount(); i < count; i++ ) {
 				var listItem = listNode.getChild( i );
 
-				// Fixing malformed nested lists by moving it into a previous list item. (#6236)
+				// Fixing malformed nested lists by moving it into a previous list item. (https://dev.ckeditor.com/ticket/6236)
 				if ( listItem.type == CKEDITOR.NODE_ELEMENT && listItem.getName() in CKEDITOR.dtd.$list )
 					CKEDITOR.plugins.list.listToArray( listItem, database, baseArray, baseIndentLevel + 1 );
 
@@ -137,13 +137,13 @@
 						currentListItem.append( item.contents[ i ].clone( 1, 1 ) );
 					currentIndex++;
 				} else if ( item.indent == Math.max( indentLevel, 0 ) + 1 ) {
-					// Maintain original direction (#6861).
+					// Maintain original direction (https://dev.ckeditor.com/ticket/6861).
 					var currDir = listArray[ currentIndex - 1 ].element.getDirection( 1 ),
 						listData = CKEDITOR.plugins.list.arrayToList( listArray, null, currentIndex, paragraphMode, currDir != orgDir ? orgDir : null );
 
 					// If the next block is an <li> with another list tree as the first
 					// child, we'll need to append a filler (<br>/NBSP) or the list item
-					// wouldn't be editable. (#6724)
+					// wouldn't be editable. (https://dev.ckeditor.com/ticket/6724)
 					if ( !currentListItem.getChildCount() && CKEDITOR.env.needsNbspFiller && doc.$.documentMode <= 7 )
 						currentListItem.append( doc.createText( '\xa0' ) );
 					currentListItem.append( listData.listNode );
@@ -364,8 +364,6 @@
 		var useComputedState = editor.config.useComputedState,
 			listDir, explicitDirection;
 
-		useComputedState = useComputedState === undefined || useComputedState;
-
 		// We want to insert things that are in the same tree level only, so calculate the contents again
 		// by expanding the selected blocks to the same tree level.
 		for ( i = 0; i < contents.length; i++ ) {
@@ -416,7 +414,7 @@
 				contentBlock.appendTo( listItem );
 			else {
 				contentBlock.copyAttributes( listItem );
-				// Remove direction attribute after it was merged into list root. (#7657)
+				// Remove direction attribute after it was merged into list root. (https://dev.ckeditor.com/ticket/7657)
 				if ( listDir && contentBlock.getDirection() ) {
 					listItem.removeStyle( 'direction' );
 					listItem.removeAttribute( 'dir' );
@@ -477,7 +475,7 @@
 
 		var newList = CKEDITOR.plugins.list.arrayToList( listArray, database, null, editor.config.enterMode, groupObj.root.getAttribute( 'dir' ) );
 
-		// Compensate <br> before/after the list node if the surrounds are non-blocks.(#3836)
+		// Compensate <br> before/after the list node if the surrounds are non-blocks.(https://dev.ckeditor.com/ticket/3836)
 		var docFragment = newList.listNode,
 			boundaryNode, siblingNode;
 
@@ -504,9 +502,9 @@
 	// Checks wheather this block should be element preserved (not transformed to <li>) when creating list.
 	function shouldPreserveBlock( block ) {
 		return (
-			// #5335
+			// https://dev.ckeditor.com/ticket/5335
 			block.is( 'pre' ) ||
-			// #5271 - this is a header.
+			// https://dev.ckeditor.com/ticket/5271 - this is a header.
 			headerTagRegex.test( block.getName() ) ||
 			// 11083 - this is a non-editable element.
 			block.getAttribute( 'contenteditable' ) == 'false'
@@ -523,7 +521,7 @@
 
 	var elementType = CKEDITOR.dom.walker.nodeType( CKEDITOR.NODE_ELEMENT );
 
-	// Merge child nodes with direction preserved. (#7448)
+	// Merge child nodes with direction preserved. (https://dev.ckeditor.com/ticket/7448)
 	function mergeChildren( from, into, refNode, forward ) {
 		var child, itemDir;
 		while ( ( child = from[ forward ? 'getLast' : 'getFirst' ]( elementType ) ) ) {
@@ -533,6 +531,7 @@
 			child.remove();
 
 			refNode ? child[ forward ? 'insertBefore' : 'insertAfter' ]( refNode ) : into.append( child, forward );
+			refNode = child;
 		}
 	}
 
@@ -556,7 +555,7 @@
 					selection.selectRanges( ranges );
 				}
 				// Maybe a single range there enclosing the whole list,
-				// turn on the list state manually(#4129).
+				// turn on the list state manually(https://dev.ckeditor.com/ticket/4129).
 				else {
 					var range = ranges.length == 1 && ranges[ 0 ],
 						enclosedNode = range && range.getEnclosedNode();
@@ -592,7 +591,8 @@
 
 				while ( ( block = iterator.getNextParagraph() ) ) {
 					// Avoid duplicate blocks get processed across ranges.
-					if ( block.getCustomData( 'list_block' ) )
+					// Avoid processing comments, we don't want to touch it.
+					if ( block.getCustomData( 'list_block' ) || hasCommentsChildOnly( block ) )
 						continue;
 					else
 						CKEDITOR.dom.element.setMarker( database, block, 'list_block', 1 );
@@ -606,13 +606,13 @@
 
 					// First, try to group by a list ancestor.
 					for ( var i = pathElementsCount - 1; i >= 0 && ( element = pathElements[ i ] ); i-- ) {
-						// Don't leak outside block limit (#3940).
+						// Don't leak outside block limit (https://dev.ckeditor.com/ticket/3940).
 						if ( listNodeNames[ element.getName() ] && blockLimit.contains( element ) ) {
 							// If we've encountered a list inside a block limit
 							// The last group object of the block limit element should
 							// no longer be valid. Since paragraphs after the list
 							// should belong to a different group of paragraphs before
-							// the list. (Bug #1309)
+							// the list. (Bug https://dev.ckeditor.com/ticket/1309)
 							blockLimit.removeCustomData( 'list_group_object_' + index );
 
 							var groupObj = element.getCustomData( 'list_group_object' );
@@ -650,11 +650,14 @@
 			while ( listGroups.length > 0 ) {
 				groupObj = listGroups.shift();
 				if ( this.state == CKEDITOR.TRISTATE_OFF ) {
-					if ( listNodeNames[ groupObj.root.getName() ] )
+					if ( isEmptyList( groupObj ) ) {
+						continue;
+					} else if ( listNodeNames[ groupObj.root.getName() ] ) {
 						changeListType.call( this, editor, groupObj, database, listsCreated );
-					else
+					} else {
 						createList.call( this, editor, groupObj, listsCreated );
-				} else if ( this.state == CKEDITOR.TRISTATE_ON && listNodeNames[ groupObj.root.getName() ] ) {
+					}
+				} else if ( this.state == CKEDITOR.TRISTATE_ON && listNodeNames[ groupObj.root.getName() ] && !isEmptyList( groupObj ) ) {
 					removeList.call( this, editor, groupObj, database );
 				}
 			}
@@ -667,6 +670,31 @@
 			CKEDITOR.dom.element.clearAllMarkers( database );
 			selection.selectBookmarks( bookmarks );
 			editor.focus();
+
+			function isEmptyList( groupObj ) {
+				// If list is without any li item, then ignore such element from transformation, because it throws errors in console (#2411, #2438).
+				return listNodeNames[ groupObj.root.getName() ] && !getChildCount( groupObj.root, [ CKEDITOR.NODE_COMMENT ] );
+			}
+
+			function getChildCount( element, excludeTypes ) {
+				return CKEDITOR.tools.array.filter( element.getChildren().toArray(), function( node ) {
+					return CKEDITOR.tools.array.indexOf( excludeTypes, node.type ) === -1;
+				} ).length;
+			}
+
+			function hasCommentsChildOnly( element ) {
+				var ret = true;
+				if ( element.getChildCount() === 0 ) {
+					return false;
+				}
+				element.forEach( function( node ) {
+					if ( node.type !== CKEDITOR.NODE_COMMENT ) {
+						ret = false;
+						return false;
+					}
+				}, null, true );
+				return ret;
+			}
 		},
 
 		refresh: function( editor, path ) {
@@ -688,7 +716,7 @@
 		function mergeSibling( rtl ) {
 			var sibling = listNode[ rtl ? 'getPrevious' : 'getNext' ]( nonEmpty );
 			if ( sibling && sibling.type == CKEDITOR.NODE_ELEMENT && sibling.is( listNode.getName() ) ) {
-				// Move children order by merge direction.(#3820)
+				// Move children order by merge direction.(https://dev.ckeditor.com/ticket/3820)
 				mergeChildren( listNode, sibling, null, !rtl );
 
 				listNode.remove();
@@ -770,7 +798,7 @@
 			nextPath = nextCursor.startPath();
 			nextBlock = nextPath.block;
 
-			// Abort when nothing to be removed (#10890).
+			// Abort when nothing to be removed (https://dev.ckeditor.com/ticket/10890).
 			if ( !nextBlock )
 				break;
 
@@ -785,7 +813,7 @@
 			nextBlock.remove();
 		}
 
-		// Check if need to further merge with the list resides after the merged block. (#9080)
+		// Check if need to further merge with the list resides after the merged block. (https://dev.ckeditor.com/ticket/9080)
 		var walkerRng = nextCursor.clone(), editable = editor.editable();
 		walkerRng.setEndAt( editable, CKEDITOR.POSITION_BEFORE_END );
 		var walker = new CKEDITOR.dom.walker( walkerRng );
@@ -811,7 +839,7 @@
 
 	CKEDITOR.plugins.add( 'list', {
 		// jscs:disable maximumLineLength
-		lang: 'af,ar,bg,bn,bs,ca,cs,cy,da,de,el,en,en-au,en-ca,en-gb,eo,es,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
+		lang: 'af,ar,az,bg,bn,bs,ca,cs,cy,da,de,de-ch,el,en,en-au,en-ca,en-gb,eo,es,es-mx,et,eu,fa,fi,fo,fr,fr-ca,gl,gu,he,hi,hr,hu,id,is,it,ja,ka,km,ko,ku,lt,lv,mk,mn,ms,nb,nl,no,oc,pl,pt,pt-br,ro,ru,si,sk,sl,sq,sr,sr-latn,sv,th,tr,tt,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
 		// jscs:enable maximumLineLength
 		icons: 'bulletedlist,bulletedlist-rtl,numberedlist,numberedlist-rtl', // %REMOVE_LINE_CORE%
 		hidpi: true, // %REMOVE_LINE_CORE%
@@ -827,12 +855,14 @@
 			// Register the toolbar button.
 			if ( editor.ui.addButton ) {
 				editor.ui.addButton( 'NumberedList', {
+					isToggle: true,
 					label: editor.lang.list.numberedlist,
 					command: 'numberedlist',
 					directional: true,
 					toolbar: 'list,10'
 				} );
 				editor.ui.addButton( 'BulletedList', {
+					isToggle: true,
 					label: editor.lang.list.bulletedlist,
 					command: 'bulletedlist',
 					directional: true,
@@ -840,10 +870,10 @@
 				} );
 			}
 
-			// Handled backspace/del key to join list items. (#8248,#9080)
+			// Handled backspace/del key to join list items. (https://dev.ckeditor.com/ticket/8248,https://dev.ckeditor.com/ticket/9080)
 			editor.on( 'key', function( evt ) {
 				// Use getKey directly in order to ignore modifiers.
-				// Justification: http://dev.ckeditor.com/ticket/11861#comment:13
+				// Justification: https://dev.ckeditor.com/ticket/11861#comment:13
 				var key = evt.data.domEvent.getKey(), li;
 
 				// DEl/BACKSPACE
@@ -908,7 +938,7 @@
 								// Place cursor at the end of previous block.
 								cursor.moveToElementEditEnd( joinWith );
 
-								// And then just before end of closest block element (#12729).
+								// And then just before end of closest block element (https://dev.ckeditor.com/ticket/12729).
 								cursor.moveToPosition( cursor.endPath().block, CKEDITOR.POSITION_BEFORE_END );
 							}
 						}
@@ -919,7 +949,7 @@
 						}
 						else {
 							var list = path.contains( listNodeNames );
-							// Backspace pressed at the start of list outdents the first list item. (#9129)
+							// Backspace pressed at the start of list outdents the first list item. (https://dev.ckeditor.com/ticket/9129)
 							if ( list && range.checkBoundaryOfElement( list, CKEDITOR.START ) ) {
 								li = list.getFirst( nonEmpty );
 
@@ -981,7 +1011,7 @@
 								nextLine = range.clone();
 								nextLine.moveToElementEditStart( next );
 
-								// #13409
+								// https://dev.ckeditor.com/ticket/13409
 								// For the following case and similar
 								//
 								// <ul>
@@ -1049,7 +1079,7 @@
 									}
 								}
 
-								// Moving `cursor` and `next line` only when at the end literally (#12729).
+								// Moving `cursor` and `next line` only when at the end literally (https://dev.ckeditor.com/ticket/12729).
 								if ( isAtEnd == 2 ) {
 									cursor.moveToPosition( cursor.endPath().block, CKEDITOR.POSITION_BEFORE_END );
 
