@@ -1,11 +1,11 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'stylescombo', 'da', {
 	label: 'Typografi',
-	panelTitle: 'Formattering på stylesheet',
-	panelTitle1: 'Block typografi',
+	panelTitle: 'Formatering på stylesheet',
+	panelTitle1: 'Blok typografi',
 	panelTitle2: 'Inline typografi',
-	panelTitle3: 'Object typografi'
+	panelTitle3: 'Objekt typografi'
 } );
